﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Net;
using System.Xml.Linq;
using VeloToulouse.Entites;

namespace VeloToulouse
{
    public class StationsService
    {
        private const string StationUrl = "http://www.velo.toulouse.fr/service/carto";
        public ObservableCollection<Station> Stations{ get; set;}
        private static StationsService _current;

        public static StationsService Current
        {
            get { if(_current == null)
                _current = new StationsService();
                return _current;
            }
            private set { _current = value; }
        }

        private StationsService()
        {
            Stations = new ObservableCollection<Station>();
        }

        public Station GetStationById(string id)
        {
            return (from s in this.Stations
                   where s.Id.Equals(id)
                   select s).FirstOrDefault();
        }

        public void GetListeStationsAsync()
        {
            var webClient = new WebClient();
            
            webClient.OpenReadCompleted += LoadCompleted;
            webClient.OpenReadAsync(new Uri(StationUrl));
        }

        private void LoadCompleted(object sender, OpenReadCompletedEventArgs e)
        {
            if (e.Error != null)
            {
                InvokeGetListeStationsCompleted(null);
                return;
            }
                
            Stream s = e.Result;
            XDocument xdoc = XDocument.Load(s);

            List<Station> res = (xdoc.Descendants("marker").Select(
                                        i => new Station{
                                            Id = i.Attribute("number").Value,
                                            Nom = i.Attribute("name").Value, 
                                            Adresse = i.Attribute("fullAddress").Value, 
                                            Latitude = i.Attribute("lat").Value, 
                                            Longitude = i.Attribute("lng").Value
                                            })).ToList();
            
            res.ForEach(item => Stations.Add(item));
            InvokeGetListeStationsCompleted(new EventArgs());
        }

        public event EventHandler GetListeStationsCompleted;

        public void InvokeGetListeStationsCompleted(EventArgs e)
        {
            EventHandler handler = GetListeStationsCompleted;
            if (handler != null) handler(this, e);
        }
    }
}